

.. _devel-macro-examples:

==============
Macro examples
==============

.. toctree::
    :maxdepth: 2
    
    Parameter examples <macro_parameter_examples>
    Calling macro examples <macro_call_examples>